import * as React from 'react';
import FacebookSharePreview from './FacebookSharePreview';
import TwitterSharePreview from './TwitterSharePreview';
import LinkedinSharePreview from './LinkedinSharePreview';
import { GoogleDesktop, GoogleMobile } from './GooglePreview';
import '../styles/socialPreview.css?raw';
function fallbackPrepare(doc) {
    if (!doc) {
        return;
    }
    // Sane defaults to what we could use for title, description, etc.
    return {
        title: doc.title || '(page not yet named)',
        description: doc.description || doc.metaDescription || doc.seoDescription,
        siteUrl: 'https://example.com',
        ogImage: doc.openGraphImage || doc.ogImage || doc.image,
        slug: doc.slug?.current || doc.relativePath?.current,
    };
}
// @TODO: select object to make it easier to re-use prepare function logic
const SocialPreview = ({ prepareFunction = fallbackPrepare, google = true, twitter = true, linkedin = true, facebook = true, } = {}) => {
    return ({ document }) => {
        const previewProps = prepareFunction(document?.displayed);
        if (!previewProps) {
            return null;
        }
        return (React.createElement(React.Fragment, null,
            google && (React.createElement(React.Fragment, null,
                React.createElement(GoogleDesktop, Object.assign({}, previewProps)),
                React.createElement(GoogleMobile, Object.assign({}, previewProps)))),
            facebook && React.createElement(FacebookSharePreview, Object.assign({}, previewProps)),
            twitter && React.createElement(TwitterSharePreview, Object.assign({}, previewProps)),
            linkedin && React.createElement(LinkedinSharePreview, Object.assign({}, previewProps))));
    };
};
export default SocialPreview;
